@@ -95,8 +95,7 @@ get_databricks_config <- function(profile) {
   config
 }
 
-mlflow_get_run_context.mlflow_databricks_client <- function(client, source_name, source_version,
-                                                            source_type, experiment_id, ...) {
+mlflow_get_run_context.mlflow_databricks_client <- function(client, experiment_id, ...) {
   if (exists(".databricks_internals")) {
     notebook_info <- do.call(".get_notebook_info", list(), envir = get(".databricks_internals",
                                                                        envir = .GlobalEnv))
@@ -105,11 +104,11 @@ mlflow_get_run_context.mlflow_databricks_client <- function(client, source_name,
       tags[[MLFLOW_DATABRICKS_TAGS$MLFLOW_DATABRICKS_NOTEBOOK_ID]] <- notebook_info$id
       tags[[MLFLOW_DATABRICKS_TAGS$MLFLOW_DATABRICKS_NOTEBOOK_PATH]] <- notebook_info$path
       tags[[MLFLOW_DATABRICKS_TAGS$MLFLOW_DATABRICKS_WEBAPP_URL]] <- notebook_info$webapp_url
+      tags[[MLFLOW_TAGS$MLFLOW_SOURCE_NAME]] <- notebook_info$path
+      tags[[MLFLOW_TAGS$MLFLOW_SOURCE_VERSION]] <- get_source_version()
+      tags[[MLFLOW_TAGS$MLFLOW_SOURCE_TYPE]] <- MLFLOW_SOURCE_TYPE$NOTEBOOK
       list(
         client = client,
-        source_version = source_version %||% get_source_version(),
-        source_type =  MLFLOW_SOURCE_TYPE$NOTEBOOK,
-        source_name = notebook_info$path,
         tags = tags,
         experiment_id = experiment_id %||% notebook_info$id,
         ...
