@@ -4,15 +4,14 @@
 #'
 #' Serves an RFunc MLflow model as a local web API.
 #'
-#' @param model_path The path to the MLflow model, as a string.
-#' @param run_uuid ID of run to grab the model from.
+#' @template roxlate-model-uri
 #' @param host Address to use to serve model, as a string.
 #' @param port Port to use to serve model, as numeric.
 #' @param daemonized Makes `httpuv` server daemonized so R interactive sessions
 #'   are not blocked to handle requests. To terminate a daemonized server, call
 #'   `httpuv::stopDaemonizedServer()` with the handle returned from this call.
+#' @param ... Optional arguments passed to `mlflow_predict()`.
 #' @param browse Launch browser with serving landing page?
-#' @param restore Should \code{mlflow_restore_snapshot()} be called before serving?
 #'
 #' @examples
 #' \dontrun{
@@ -32,32 +31,26 @@
 #' @importFrom jsonlite fromJSON
 #' @import swagger
 #' @export
-mlflow_rfunc_serve <- function(
-  model_path,
-  run_uuid = NULL,
-  host = "127.0.0.1",
-  port = 8090,
-  daemonized = FALSE,
-  browse = !daemonized,
-  restore = FALSE
-) {
-  mlflow_restore_or_warning(restore)
-
-  model_path <- resolve_model_path(model_path, run_uuid)
-
+mlflow_rfunc_serve <- function(model_uri,
+                               host = "127.0.0.1",
+                               port = 8090,
+                               daemonized = FALSE,
+                               browse = !daemonized,
+                               ...) {
+  model_path <- mlflow_download_artifacts_from_uri(model_uri)
   httpuv_start <- if (daemonized) httpuv::startDaemonizedServer else httpuv::runServer
-  serve_run(model_path, host, port, httpuv_start, browse && interactive())
+  serve_run(model_path, host, port, httpuv_start, browse && interactive(), ...)
 }
 
 serve_content_type <- function(file_path) {
   file_split <- strsplit(file_path, split = "\\.")[[1]]
   switch(file_split[[length(file_split)]],
-         "css" = "text/css",
-         "html" = "text/html",
-         "js" = "application/javascript",
-         "json" = "application/json",
-         "map" = "text/plain",
-         "png" = "image/png"
+    "css" = "text/css",
+    "html" = "text/html",
+    "js" = "application/javascript",
+    "json" = "application/json",
+    "map" = "text/plain",
+    "png" = "image/png"
   )
 }
 
@@ -99,7 +92,7 @@ serve_invalid_request <- function(message = NULL) {
   )
 }
 
-serve_prediction <- function(json_raw, model) {
+serve_prediction <- function(json_raw, model, ...) {
   mlflow_verbose_message("Serving prediction: ", json_raw)
 
   df <- data.frame()
@@ -113,7 +106,7 @@ serve_prediction <- function(json_raw, model) {
 
   df <- as.data.frame(df)
 
-  mlflow_predict_flavor(model, df)
+  mlflow_predict(model, df, ...)
 }
 
 serve_empty_page <- function(req, sess, model) {
@@ -126,7 +119,7 @@ serve_empty_page <- function(req, sess, model) {
   )
 }
 
-serve_handlers <- function(host, port) {
+serve_handlers <- function(host, port, ...) {
   handlers <- list(
     "^/swagger.json" = function(req, model) {
       list(
@@ -152,7 +145,7 @@ serve_handlers <- function(host, port) {
     "^/predict" = function(req, model) {
       json_raw <- req$rook.input$read()
 
-      results <- serve_prediction(json_raw, model)
+      results <- serve_prediction(json_raw, model, ...)
 
       list(
         status = 200L,
@@ -160,7 +153,7 @@ serve_handlers <- function(host, port) {
           "Content-Type" = paste0(serve_content_type("json"), "; charset=UTF-8")
         ),
         body = charToRaw(enc2utf8(
-          jsonlite::toJSON(list(predictions = results), auto_unbox = TRUE)
+          jsonlite::toJSON(results, auto_unbox = TRUE, digits = NA)
         ))
       )
     },
@@ -188,14 +181,14 @@ message_serve_start <- function(host, port, model) {
 }
 
 #' @importFrom utils browseURL
-serve_run <- function(model_path, host, port, start, browse) {
+serve_run <- function(model_path, host, port, start, browse, ...) {
   model <- mlflow_load_model(model_path)
 
   message_serve_start(host, port, model)
 
   if (browse) browseURL(paste0("http://", host, ":", port))
 
-  handlers <- serve_handlers(host, port)
+  handlers <- serve_handlers(host, port, ...)
 
   start(host, port, list(
     onHeaders = function(req) {
